

class CatToggler {

	private var enabled : bool;

	private saved var highlightObjectsRange, highlightEnemiesRange : float;
	private var witcher : W3PlayerWitcher;				//cached witcher object to avoid casting each tick
	private var timeSinceLastHighlight, timeSinceLastEnemyHighlight : float;
	private const var HIGHLIGHT_REFRESH_DT, ENEMY_HIGHLIGHT_DT : float;

	default HIGHLIGHT_REFRESH_DT = 0.5;
	default ENEMY_HIGHLIGHT_DT = 1.0f;

	public function Init(player : W3PlayerWitcher)
	{
		var min, max : SAbilityAttributeValue;

		witcher = player;

		enabled = false;

		theGame.GetDefinitionsManager().GetAbilityAttributeValue('CatEffect_Level3', 'highlightObjectsRange', min, max);
		highlightObjectsRange = CalculateAttributeValue(GetAttributeRandomizedValue(min, max));

		theGame.GetDefinitionsManager().GetAbilityAttributeValue('CatEffect_Level3', 'highlightEnemiesRange', min, max);
		highlightEnemiesRange = CalculateAttributeValue(GetAttributeRandomizedValue(min, max));

		timeSinceLastHighlight = 0;
		timeSinceLastEnemyHighlight = 0;

		theInput.RegisterListener( this, 'toggle', 'ToggleCat' );
	}

	private function toggle(action : SInputAction) 
	{
		if(IsPressed (action) && !enabled) 
		{
			enabled = true;

			timeSinceLastHighlight = 0;
			timeSinceLastEnemyHighlight = 0;

			toggleEffect(true);	
				
		}	
		else if(IsPressed (action) && enabled) 
		{
			enabled = false;
			toggleEffect(false);
		}
	}

	private function toggleEffect(en : bool)
	{
		if(en)
		{
			EnableCatViewFx( 1.0f );	// enable effect and blend it in over 1 sec
			SetTintColorsCatViewFx(Vector(0.1f,0.12f,0.13f,0.6f),Vector(0.075f,0.1f,0.11f,0.6f),0.2f);
			SetBrightnessCatViewFx(350.0f);
			SetViewRangeCatViewFx(200.0f);
			SetPositionCatViewFx( Vector(0,0,0,0) , true );	// Set auto poistioning
			SetHightlightCatViewFx( Vector(0.5f,0.2f,0.2f,1.f),0.05f,1.5f);
			SetFogDensityCatViewFx( 0.5 );
		}
		else
		{
			DisableCatViewFx( 1.0f );
		}
	}

	public function Update( dt : float )
	{
		if(!enabled) 
		{
			return; 
		}

		if(highlightObjectsRange > 0)			
		{
			timeSinceLastHighlight += dt;
			
			if(timeSinceLastHighlight >= HIGHLIGHT_REFRESH_DT)
			{
				timeSinceLastHighlight = 0;
				witcher.HighlightObjects(highlightObjectsRange, 1);
			}
		}
		
		//highlight enemies
		if(highlightEnemiesRange > 0)			
		{
			timeSinceLastEnemyHighlight += dt;
			
			if(timeSinceLastEnemyHighlight >= ENEMY_HIGHLIGHT_DT * 0.9f )
			{
				timeSinceLastEnemyHighlight = 0;
				witcher.HighlightEnemies( highlightEnemiesRange, ENEMY_HIGHLIGHT_DT );
			}
		}
	}			
}